Installing cygenja — cygenja 0.5.1 documentation

# Installing cygenja

Installing cygenja is really easy.

## Dependencies

The only dependency is the Jinja2 library.

If you want to generate the documentation, you need Sphinx and the sphinx_bootstrap_theme (and possibly LaTeX and several sub modules/packages). To generate the documentation, cygenja does not need to be installed.

## Installation

Download source files from Github (or clone the repository) and invoke the traditionnal:

    python setup.py install

in a virtual environment or globally with full admin rights.